@@ -30,14 +30,17 @@
 static PyObject *
 pyg_enum_richcompare(PyGEnum *self, PyObject *other, int op)
 {
+    static char warning[256];
+
     if (!PyInt_Check(other)) {
 	Py_INCREF(Py_NotImplemented);
 	return Py_NotImplemented;
     }
 
     if (PyObject_TypeCheck(other, &PyGEnum_Type) && ((PyGEnum*)other)->gtype != self->gtype) {
-	PyErr_Warn(PyExc_Warning, "comparing different enum types");
-	return NULL;
+	g_snprintf(warning, sizeof(warning), "comparing different enum types: %s and %s",
+		   g_type_name(self->gtype), g_type_name(((PyGEnum*)other)->gtype));
+	PyErr_Warn(PyExc_Warning, warning);
     }
 
     return pyg_integer_richcompare((PyObject *)self, other, op);
@@ -47,7 +50,7 @@ static PyObject *
 pyg_enum_repr(PyGEnum *self)
 {
   GEnumClass *enum_class;
-  char *value;
+  const char *value;
   guint index;
   static char tmp[256];
   
@@ -174,7 +177,11 @@ pyg_enum_add (PyObject *   module,
     int i;
     
     g_return_val_if_fail(typename != NULL, NULL);
-    g_return_val_if_fail(g_type_is_a(gtype, G_TYPE_ENUM), NULL);
+    if (!g_type_is_a(gtype, G_TYPE_ENUM)) {
+        g_warning("Trying to register gtype '%s' as enum when in fact it is of type '%s'",
+                  g_type_name(gtype), g_type_name(G_TYPE_FUNDAMENTAL(gtype)));
+        return NULL;
+    }
     
     state = pyg_gil_state_ensure();
 
@@ -225,10 +232,12 @@ pyg_enum_add (PyObject *   module,
         Py_DECREF(intval);
 	
 	if (module) {
-	    PyModule_AddObject(module,
-			       pyg_constant_strip_prefix(eclass->values[i].value_name,
-							 strip_prefix),
-			       item);
+	    char *prefix;
+
+	    prefix = g_strdup(pyg_constant_strip_prefix(eclass->values[i].value_name, strip_prefix));
+	    PyModule_AddObject(module, prefix, item);
+	    g_free(prefix);
+
 	    Py_INCREF(item);
 	}
     }
